@@ -28,10 +28,12 @@ class ProxyHandler:
         logger.info(f'<Proxy> {origin_url}')
 
         if not origin_url:
+            handler_context.is_proxiable = False
             return
 
         parsed_url = urllib.parse.urlparse(origin_url)
         if not parsed_url.hostname:
+            handler_context.is_proxiable = False
             return
         elif parsed_url.hostname in ['localhost', '127.0.0.1', ] and parsed_url.port == application.config["mock.port"]:
             DuplicateRequest().handle(handler_context)
@@ -62,5 +64,3 @@ class ProxyHandler:
             stream_with_context(r.iter_content(chunk_size=handler_context.response_chunk_size)),
             status=r.status_code,
             headers=resp_headers)
-
-        handler_context.update_response_headers_code2flow()
